==> elektra-0.8.20.tar.gz: elektra-0.8.20/doc/tutorials/README.md <==
Elektra has many different aspects to explore.
Not all parts are needed by everyone.
In this document we classify which parts should
be read by whom.

## General Information

Read this first to get the basic concepts of Elektra.

- [Namespaces](namespaces.md)
- [Cascading](cascading.md)
- [Mount Configuration Files](mount.md)

## Developers

For these tutorials we assume you want to elektrify your
application, that means, you want your application
to participate in the global key database Elektra
provides.

- [Integration of your Application](application-integration.md)
- [Hello, Elektra](hello-elektra.md)
- [Plugins Introduction](plugins.md)
- [Compilation Variants of plugins](compilation-variants.md) (advanced topic)
- [Python Bindings](python-kdb.md)
- [Ruby Bindings](/src/bindings/swig/ruby/README.md)
- [Code Generation](/src/tools/gen/README.md)

## System Administrators

For these tutorials we assume that you want to
work with the configuration of applications
already somehow integrated with Elektra.

- [Import Configuration](import.md)
- [Export Configuration](export.md)
- [Intercept Environment](/src/bindings/intercept/env/README.md)
- [Intercept File System](/src/bindings/intercept/fs/README.md)
- [Merge Configuration](merge.md)
- [Validate Configuration](validation.md)

## Package Maintainers

For these tutorials we assume that you maintain
upstream packages.

- [Merge Configuration Files](elektra-merge-integration.md)

## Installation Manuals

These tutorials provide additional information on how to
install and set up specific plugins and tools.

- [Snippet Sharing REST-Service](snippet-sharing-rest-service.md)

==> elektra-0.9.2.tar.gz: elektra-0.9.2/doc/tutorials/README.md <==
Elektra has many different aspects to explore.
Not all parts are needed by everyone.
In this document we classify which parts should
be read by whom.

## General Information

Read this first to get the basic concepts of Elektra.

- [Namespaces](namespaces.md)
- [Cascading](cascading.md)
- [Arrays](arrays.md)
- [Mount Configuration Files](mount.md)

## Developers

For these tutorials we assume you want to elektrify your
application, that means, you want your application
to participate in the global key database Elektra
provides.

- [Integration of your Application](application-integration.md)
- [Hello, Elektra](hello-elektra.md)
- [Plugins Introduction](plugins.md)
- [Storage Plugins](storage-plugins.md)
- [Compilation Variants of plugins](compilation-variants.md) (advanced topic)
- [High Level API](highlevel.md)
- [Command Line Options](command-line-options.md)
- [Python Bindings](python-kdb.md)
- [Java Bindings](java-kdb.md)
- [Java Plugins](java-plugins.md)
- [Ruby Bindings](/src/bindings/swig/ruby/README.md)
- [Notifications](notifications.md)

## System Administrators

For these tutorials we assume that you want to
work with the configuration of applications
already somehow integrated with Elektra.

- [Import Configuration](import.md)
- [Export Configuration](export.md)
- [Intercept Environment](/src/bindings/intercept/env/README.md)
- [Intercept File System](/src/bindings/intercept/fs/README.md)
- [Merge Configuration](cmerge.md) (new version)
- [Merge Configuration](merge.md) (deprecated)
- [Validate Configuration](validation.md)
- [Encrypt Configuration](crypto.md)

## Elektra Developers

These tutorials are for persons that want to contribute to
Elektra:

- [Contributing with CLion](contributing-clion.md)
- [Benchmarking](benchmarking.md)
- [Profiling](profiling.md)
- [Run all Tests with Docker](run_all_tests_with_docker.md)
- [Run Reformatting with Docker](run_reformatting_script_with_docker.md)
- [Language Bindings](language-bindings.md)
- [Code generator](code-generator.md)

## Installation Manuals

These tutorials provide additional information on how to
install and set up specific plugins and tools.

- [Snippet Sharing REST-Service](snippet-sharing-rest-service.md)
- [Webui](install-webui.md)
